@@ -1,5 +1,6 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 
+from .datapoint_diff import datapoint_diff_over_time_period
 from .gaps_identification import (
     gaps_identification_iqr,
     gaps_identification_modified_z_scores,
@@ -20,6 +21,21 @@ from .value_decrease_indication import value_decrease_check
 TOOLBOX_NAME = "Data quality"
 
 __all__ = [
+    "datapoint_diff_over_time_period",
+    "extreme",
+    "gaps_identification_iqr",
+    "gaps_identification_modified_z_scores",
+    "gaps_identification_threshold",
+    "gaps_identification_z_scores",
+    "low_density_identification_iqr",
+    "low_density_identification_modified_z_scores",
+    "low_density_identification_threshold",
+    "low_density_identification_z_scores",
+    "rolling_stddev_timedelta",
+    "value_decrease_check",
+]
+
+__cognite__ = [
     "gaps_identification_z_scores",
     "gaps_identification_modified_z_scores",
     "gaps_identification_iqr",
@@ -31,4 +47,5 @@ __all__ = [
     "extreme",
     "value_decrease_check",
     "rolling_stddev_timedelta",
+    "datapoint_diff_over_time_period",
 ]
