@@ -1,15 +1,15 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 import numpy as np
 import pandas as pd
 
-from ..ts_utils.utility_functions import (
+from indsl.ts_utils.utility_functions import (
     generate_step_series,
     modified_z_scores_test,
     normality_assumption_test,
     z_scores_test,
 )
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index, validate_series_is_not_empty
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index, validate_series_is_not_empty
 
 
 @check_types
@@ -170,11 +170,11 @@ def gaps_identification_threshold(data: pd.Series, time_delta: pd.Timedelta = pd
 
     last_index = data.index[-1]
 
-    diff = data.index.to_series().diff().shift(-1).dropna()
+    diff = data.index.astype("datetime64[ns]").to_series().diff().shift(-1).dropna()
     is_gap_series = diff > time_delta
     is_gap_series = is_gap_series.astype(int)
 
     # duplicate the last flag value since the flag series should have the same length as the original data points
-    flag_series = pd.concat([is_gap_series, pd.Series(is_gap_series[-1], index=[last_index])])
+    flag_series = pd.concat([is_gap_series, pd.Series(is_gap_series.iloc[-1], index=[last_index])])
 
     return generate_step_series(flag_series)
