@@ -1,12 +1,12 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import Literal, Optional
 
 import numpy as np
 import pandas as pd
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index, validate_series_is_not_empty
+from indsl.exceptions import MATPLOTLIB_REQUIRED, UserValueError
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index, validate_series_is_not_empty
 
 
 class Cusum:
@@ -70,7 +70,12 @@ class Cusum:
         Raises:
             UserTypeError: If a time series with the wrong index is provided.
             UserValueError: If an empty time series is passed into the function.
+            UserValueError: If the alpha value is not in the range (0, 1].
         """
+        # Check for correct alpha value
+        if not (0 < alpha <= 1):
+            raise UserValueError(f"Invalid alpha value: {alpha}. Alpha should be in the range (0, 1].")
+
         self.data = data
         self._validate_time_series()
 
@@ -84,7 +89,7 @@ class Cusum:
         # smooth time series used as mean data
         self.mean_data = data.ewm(alpha=alpha).mean()
 
-        # store results
+        # initialize empty results
         self.time_alarm = np.array([])
         self.time_alarm_initial = np.array([])
         self.time_alarm_final = np.array([])
@@ -205,9 +210,9 @@ class Cusum:
         2. Cumulative sums for increasing and decreasing changes.
         """
         try:
-            import matplotlib.pyplot as plt
+            from matplotlib import pyplot as plt
         except ImportError:
-            raise ImportError("matplotlib is not available.")
+            raise ImportError(MATPLOTLIB_REQUIRED)
         else:
             _, (ax1, ax2) = plt.subplots(2, 1, figsize=(15, 10))
             time_alarm_initial_index = [pd.Timestamp(self.data.index[tai_val]) for tai_val in self.time_alarm_initial]
@@ -220,7 +225,7 @@ class Cusum:
             if len(self.time_alarm):
                 ax1.plot(
                     time_alarm_initial_index,
-                    self.data[self.time_alarm_initial],
+                    self.data.iloc[self.time_alarm_initial],
                     ">",
                     mfc="b",
                     mec="g",
@@ -356,7 +361,7 @@ def cusum(
             If fewer false alarms are wanted, try to increase `drift`.
             If the threshold is not provided, it is assigned to (2 * data_standard_deviation - data_mean) / 2.
         detect: Type of changes to detect.
-              Options are:
+                Options are:
                 * "both" for detecting both increasing and decreasing changes in the data (default)
                 * "increase" for detecting increasing changes in the data
                 * "decrease" for detecting decreasing changes in the data
