@@ -1,10 +1,10 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 import numpy as np
 import pandas as pd
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index
+from indsl.exceptions import UserValueError
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index
 
 
 @check_types
@@ -44,7 +44,7 @@ def resample_timeseries(data: pd.Series, is_step: bool = False) -> pd.Series:
 
     # interpolate missing values
     if is_step:
-        data_interpolated = data_missing_values.interpolate(method="ffill")
+        data_interpolated = data_missing_values.ffill()
     else:
         data_interpolated = data_missing_values.interpolate(method="time")
 
