@@ -1,18 +1,16 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
+
 from typing import Literal
 
 import pandas as pd
 
-from skimage.restoration import denoise_wavelet
-
 from indsl import versioning
+from indsl.exceptions import SCIKIT_IMAGE_REQUIRED, UserValueError
+from indsl.type_check import check_types
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
 from . import wavelet_filter_v1  # noqa
 
 
-# TODO: Add more wavelet types from https://pywavelets.readthedocs.io/en/latest/ref/wavelets.html
 wavelet_options = Literal[
     "db1",
     "db2",
@@ -62,7 +60,11 @@ def wavelet_filter(data: pd.Series, level: int = 2, wavelet: wavelet_options = "
     Returns:
         pandas.Series: Filtered time series.
     """
-    # TODO: Add more info about wavelet type input in docstrings
+    try:
+        from skimage.restoration import denoise_wavelet
+    except ImportError:
+        raise ImportError(SCIKIT_IMAGE_REQUIRED)
+
     if level <= 0:
         raise UserValueError("The level value needs to be a positive integer")
     if level >= len(data.values):
