@@ -1,19 +1,20 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
+from typing import Optional
+
 import numpy as np
 import pandas as pd
 
+from indsl.exceptions import UserValueError
 from indsl.type_check import check_types
 
-from ..exceptions import UserValueError
-
 
 @check_types
 def calculate_shutin_interval(
     shut_valve: pd.Series,
-    min_shutin_len: int = 6,
-    min_time_btw_shutins: int = 1,
+    min_shutin_len: float = 6,
+    min_time_btw_shutins: float = 1,
     shutin_state_below_threshold: bool = True,
-    shutin_threshold: int = None,
+    shutin_threshold: Optional[float] = None,
 ) -> pd.Series:
     """Shut-in interval.
 
@@ -52,6 +53,9 @@ def calculate_shutin_interval(
     else:
         wvalve["valve_state"] = np.where(wvalve["valve_state_org"] > shutin_threshold, 0, 1)
     wvalve["valve_diff"] = wvalve["valve_state"].diff()
+    if wvalve["valve_diff"].std() == 0:
+        # no change in state, return the original state
+        return wvalve["valve_state"].rename(None)
     wvalve["final_indicator"] = 1
     wvalve = wvalve.dropna()
 
@@ -62,21 +66,22 @@ def calculate_shutin_interval(
     if sh_start and sh_end:
         # case 1: several shut-ins exist - the shut-in comes from the past - make a pseudo-start of the shut-in
         if sh_end[0] < sh_start[0]:
-            sh_start = [wvalve.iloc[0, :]["timestamp"]] + sh_start
+            sh_start = [wvalve.iloc[0, :]["timestamp"], *sh_start]
         # case 2: several shut-ins exist - the shut-in goes to the future - make a pseudo-end of shut-in
         if sh_end[-1] < sh_start[-1]:
-            sh_end = sh_end + [wvalve.iloc[-1, :]["timestamp"]]
+            sh_end = [*sh_end, wvalve.iloc[-1, :]["timestamp"]]
     elif not sh_start:
         # case 3: only one shut-in exist - the shut-in comes from the past - make a pseudo-start of the shut-in
-        sh_start = [wvalve.iloc[0, :]["timestamp"]] + sh_start
+        sh_start = [wvalve.iloc[0, :]["timestamp"], *sh_start]
     else:
         # case 4: only one shut-in exist - the shut-in comes from the past - make a pseudo-start of the shut-in
-        sh_end = sh_end + [wvalve.iloc[-1, :]["timestamp"]]
+        sh_end = [*sh_end, wvalve.iloc[-1, :]["timestamp"]]
     time_pairs = list(zip(sh_start, sh_end))
 
     # merge the shut-ins based on the minimum distance between consecutive shut-ins
     time_pairs_upd = []
     time_pairs.append(time_pairs[-1])
+
     i = 0
     new_pair = time_pairs[i]
     time_pairs_upd.append(new_pair)
