@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import List, Literal
 
 import numpy as np
@@ -7,10 +7,10 @@ import pandas.core.indexes.datetimes
 import scipy
 
 from indsl import versioning
+from indsl.exceptions import UserTypeError, UserValueError
 from indsl.ts_utils.ts_utils import functional_mean
+from indsl.type_check import check_types
 
-from ..exceptions import UserTypeError, UserValueError
-from ..type_check import check_types
 from . import reindex_v1  # noqa
 
 
@@ -136,7 +136,7 @@ def reindex_many(
         idx_common = idx_common[start_loc : stop_loc + 1]
 
     if len(idx_common) == 0:
-        raise UserTypeError("The re-indexed time series is empty.")
+        raise UserValueError("The re-indexed time series is empty.")
 
     # Reindex data to common index
     out = [_reindex(d, idx_common, method, kind, bounded) for d in data]
@@ -159,9 +159,17 @@ def _reindex(
     observations = data.dropna()
 
     # x and y datapoints used to construct linear piecewise function
-    x_observed = observations.index.view(np.int64)
+    x_observed = pd.Series(observations.index.view(np.int64))
     y_observed = observations.values
 
+    # Check for duplicate x values
+    if x_observed.duplicated().any():
+        raise UserValueError("x_observed should not contain duplicates.")
+
+    # Check for duplicate values of new_index
+    if pd.Series(x_uniform).duplicated().any():
+        raise UserValueError("new_index should not contain duplicates.")
+
     if bounds_error:
         fill_value = None
     else:
