@@ -1,3 +1,4 @@
+# Copyright 2023 Cognite AS
 import warnings
 
 from typing import Any, List, Literal, Optional, Union
@@ -5,9 +6,12 @@ from typing import Any, List, Literal, Optional, Union
 import numpy as np
 import pandas as pd
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index
+from indsl.exceptions import UserValueError
+from indsl.signals.noise import RedNoise, Sinusoidal, TimeSampler, TimeSeries
+from indsl.ts_utils.utility_functions import TimeUnits
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index
+from indsl.warnings import IndslUserWarning
 
 
 @check_types
@@ -116,7 +120,7 @@ def sine_wave(
             Date-time string when the time series starts. The date must be a string, for example:
             "1975-05-09 20:09:10".
         end_date: End date
-            Date-time string when the time series starts. The date must be a string, for example:
+            Date-time string when the time series ends. The date must be a string, for example:
             "1975-05-09 20:09:10".
         sample_freq: Frequency.
             Sampling frequency as a time delta, value, and time unit. Defaults to '1 minute'. Valid time units are:
@@ -164,14 +168,101 @@ def sine_wave(
 
     idx = _make_index(start=start_date, end=end_date, freq=sample_freq)
 
-    wave_period = wave_period / pd.Timedelta(1, unit="s")
+    wave_period_ = wave_period / pd.Timedelta(1, unit="s")
 
-    angular_freq = 2 * np.pi * (1 / wave_period)
+    angular_freq = 2 * np.pi * (1 / wave_period_)
     wave_data = wave_amplitude * np.sin(angular_freq * _time_array(idx) + wave_phase) + wave_mean
 
     return pd.Series(data=wave_data, index=idx, name="Sine wave")
 
 
+@check_types
+def wave_with_brownian_noise(
+    duration: int = 14400,
+    resolution: float = 0.5,
+    percentage: float = 100,
+    amplitude: float = 10,
+    mean: float = 200,
+    frequency: float = 0.04,
+    noise: List[int] = [1, 1],
+):
+    """Wave with brownian noise.
+
+    Sinusoidal signal with brownian noise. The signal has a
+    given duration of 4 hours as a default, a resolution of 0.5,
+    an amplitude of 10, a mean of 200 and a frequency of 0.04 Hz.
+
+
+    Args:
+        duration: Duration.
+            Duration of the time series in seconds. Defaults to 14400.
+        resolution: Resolution.
+            Frequency resolution. Defaults to 0.5.
+        percentage: Percentage.
+            Percentage of the time series to keep. Defaults to 100.
+        amplitude: Amplitude.
+            Amplitude of the wave. Defaults to 10.
+        mean: Mean.
+            Mean of the wave. Defaults to 200.
+        frequency: Frequency.
+            Frequency of the wave. Defaults to 0.04 Hz.
+        noise: Noise.
+            Noise of the wave. Defaults to [1, 1].
+
+    Returns:
+        pd.Series:
+            Sine wave with brownian noise.
+    """
+    # Initializing TimeSampler
+    time_sampler = TimeSampler(stop_time=duration)
+    # Sampling irregular time samples
+    time_vector = time_sampler.sample_irregular_time(resolution=resolution, keep_percentage=percentage)
+
+    # Initializing Sinusoidal signal
+    sinusoid = Sinusoidal(amplitude=amplitude, frequency=frequency)
+
+    # Initializing Red (Brownian) noise
+    red_noise = RedNoise(std=noise[0], tau=noise[1])
+
+    # Initializing TimeSeries class with the signal and noise objects
+    timeseries_corr = TimeSeries(sinusoid, noise_generator=red_noise)
+
+    # Sampling using the irregular time samples
+    data_points, signals_corr, errors_corr = timeseries_corr.sample(time_vector)
+    data_points = data_points + mean
+
+    time_vector = pd.to_datetime(time_vector, unit="s")
+    return pd.Series(data=data_points, index=time_vector)
+
+
+@check_types
+def _get_sample_frequency(sample_freq: float, unit: TimeUnits):
+    """Get sample frequency.
+
+    Helper method to convert the frequency magnitude and units into a string
+    that is then used by other function to generate DatetimeIndex data.
+
+    Args:
+        sample_freq: Frequency magnitude
+        unit: Time unit
+            Valid values "ns|us|ms|s|m|h|d|W". Default is "m" (minutes)
+
+    Returns:
+        str: Frequency string
+
+    """
+    if unit == "m":
+        use_unit = "min"
+    elif unit == "s":
+        use_unit = "s"
+    elif unit == "W":
+        use_unit = "d"
+        sample_freq = sample_freq * 7
+    else:
+        use_unit = unit
+    return pd.Timedelta(sample_freq, use_unit)
+
+
 @check_types
 def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     """Perturb timestamp.
@@ -205,10 +296,7 @@ def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     ts = data.copy()
     ts.index += pd.to_timedelta(time_perturbations, "sec")
     ts.index = ts.index.sort_values()
-    # TODO: Add example for Gallery of Charts
 
-    # TODO: Sughestion from Hakon Treider. Another possibility is to do a cumulative sum on time_perturbations to make
-    # the jumps "more continuous" / "higher temporal locality".
     return ts.sort_index()
 
 
@@ -278,7 +366,7 @@ def insert_data_gaps(
         gap_loc = rng.choice(np.arange(1, original_length - 1), size=points_to_remove, replace=False, shuffle=False)
         return data.loc[data.index.difference(data.index[gap_loc])]
     elif method == "Single":
-        gap_loc = int(rng.integers(low=buffer1, high=buffer2, size=1))
+        gap_loc = rng.integers(low=buffer1, high=buffer2, size=1)[0]
         # Move the start of the gap location away from the end of the time series so that the data gap ends right
         # at the buffer
         if gap_loc + points_to_remove > buffer2:
@@ -298,20 +386,20 @@ def insert_data_gaps(
         # Generate random gap location, sizes and loc ranges that amount to the fraction of data to be removed
         gap_loc = np.sort(rng.integers(low=buffer1, high=buffer2, size=num_gaps))
         gap_size = _random_list_of_integers_that_gives_exact_sum(list_length=num_gaps, sum_output=points_to_remove)
-        gap_ranges = list(
-            zip(gap_loc, gap_loc + gap_size - 1)
+        gap_ranges = np.array(
+            list(zip(gap_loc, gap_loc + gap_size - 1))
         )  # BE CAREFUL WITH EDGE RANGE INCLUDING/EXCLUDING LAST DATA POINT
 
-        gap_ranges = _handle_overlapping_gaps(gap_ranges=gap_ranges, data_length=len(data))
-        idx_loc: List[np.array] = []
-        for ii in range(len(gap_ranges)):
-            idx_loc = np.append(idx_loc, np.arange(gap_ranges[ii][0], gap_ranges[ii][1] + 1, dtype=int)).astype(int)
+        gap_ranges_ = _handle_overlapping_gaps(gap_ranges=gap_ranges, data_length=len(data))
+        idx_loc: np.ndarray = np.array([])
+        for ii in range(len(gap_ranges_)):
+            idx_loc = np.append(idx_loc, np.arange(gap_ranges_[ii][0], gap_ranges_[ii][1] + 1, dtype=int)).astype(int)
         idx = data.index[idx_loc]
         return data.drop(labels=idx)
 
 
 @check_types
-def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int = 5) -> np.ndarray:
+def _handle_overlapping_gaps(gap_ranges: np.ndarray, data_length: int, buffer: int = 5) -> np.ndarray:
     """Handle overlapping gaps.
 
     Internal method to handle overlapping gaps. The method calculates the
@@ -487,7 +575,15 @@ def _make_index(
     # Catch strange sample frequency inputs
     if not isinstance(freq, pd.Timedelta):
         freq = pd.Timedelta(1, "m")
-        warnings.warn("Can't recognize the sample frequency, setting it to the '1 m' default.")
+        warnings.warn(
+            "Can't recognize the sample frequency, setting it to the '1 m' default.", category=IndslUserWarning
+        )
+
+    if freq.total_seconds() <= 0:
+        raise UserValueError(
+            f"The sampling frequency must be a value higher than zero. "
+            f"The value provided was {freq.total_seconds()}"
+        )
 
     index = pd.date_range(start=start_date, end=end_date, freq=freq)
     return index
