@@ -1,8 +1,9 @@
+# Copyright 2023 Cognite AS
 from typing import List
 
 import pandas as pd
 
-from ..type_check import check_types
+from indsl.type_check import check_types
 
 
 @check_types
@@ -17,13 +18,13 @@ def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1
         y = a_0 + a_1x + a_2x^2 + a_3x^3 + ... + a_nx^n
 
     Args:
-        signal: Time series
-        coefficients: Coefficients.
-            List of coefficients separated by semicolons. The numbers must be entered, separated by semicolons (e.g., 0; 1).
-            The default is :math:`0.0; 1.0`, which returns the original time series.
+        signal (pandas.Series): Time series
+        coefficients (List[float]): Coefficients
+            List of coefficients separated by commas. The numbers must be entered separated by commas (e.g., 0, 1).
+            The default is :math:`0.0, 1.0`, which returns the original time series.
 
     Returns:
-        pandas.Series: Output
+        pd.Series: Output
     """
     poly = pd.Series(0, index=signal.index)
     n = 0
