@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import Literal
 
 import pandas as pd
@@ -6,18 +6,19 @@ import pandas as pd
 from scipy.signal import butter, sosfilt
 
 from indsl import versioning
+from indsl.exceptions import UserValueError
 from indsl.type_check import check_types
 
 from . import butterworth_v1  # noqa
 
 
 # noinspection SpellCheckingInspection
-@check_types
 @versioning.register(
     version="2.0",
     changelog="Unused or irrelevant lines of code removed and filter output parameter "
     "removed from function signature and set to `sos`.",
 )
+@check_types
 def butterworth(
     data: pd.Series,
     N: int = 50,
@@ -49,7 +50,8 @@ def butterworth(
 
     if len(data) < 1:
         return data
-
+    if (Wn <= 0) or (Wn >= 1):
+        raise UserValueError("Critical frequency must be between 0 and 1")
     filter_output = butter(N=N, Wn=Wn, output="sos", btype=btype)
     # Apply second order segments
     filtered = sosfilt(filter_output, data, axis=0)
