@@ -1,16 +1,18 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
+from typing import Optional
+
 import pandas as pd
 
 from scipy.signal import savgol_filter
 
-from ..exceptions import UserValueError
+from indsl.exceptions import UserValueError
 
 # noinspection SpellCheckingInspection
-from ..type_check import check_types
+from indsl.type_check import check_types
 
 
 @check_types
-def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Series:
+def sg(data: pd.Series, window_length: Optional[int] = None, polyorder: int = 1) -> pd.Series:
     """Saviztky-Golay.
 
     Use this filter for smoothing data without distorting the data tendency. The method is independent of
@@ -39,9 +41,6 @@ def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Ser
         UserValueError: The polynomial order must be less than the window length
     """
     if window_length is None:
-        # window_length calculation
-        # Filter window based on the average number of data points per second
-        # avg_dps = np.mean(np.diff(series.index)) / np.timedelta64(1, "s")
         window_length = len(data) // 5
     if window_length % 2 == 0:
         window_length += 1  # The filter requires the window to be odd
