@@ -1,21 +1,27 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 import numpy as np
 import numpy.typing as npt
 import pandas as pd
 
-from numba import njit, prange
 from scipy.integrate import cumulative_trapezoid
 
 from indsl import versioning
-from indsl.exceptions import UserValueError
+from indsl.decorators import njit
+from indsl.exceptions import NUMBA_REQUIRED, UserValueError
 from indsl.type_check import check_types
 from indsl.validations import validate_series_has_minimum_length, validate_series_is_not_empty, validate_timedelta
 
 from . import numerical_calculus_v1  # noqa
 
 
-@check_types
+try:
+    from numba import prange
+except ImportError:
+    prange = None  # Only core dependencies installed. Will raise an error later
+
+
 @versioning.register(version="2.0", changelog="Removed granlularity argument; updated parameter types")
+@check_types
 def trapezoidal_integration(series: pd.Series, time_unit: pd.Timedelta = pd.Timedelta("1 h")) -> pd.Series:
     """Integration.
 
@@ -37,8 +43,8 @@ def trapezoidal_integration(series: pd.Series, time_unit: pd.Timedelta = pd.Time
     return pd.Series(arr, index=series.index)
 
 
-@check_types
 @versioning.register(version="2.0", changelog="Removed granlularity argument; updated parameter types")
+@check_types
 def differentiate(series: pd.Series, time_unit: pd.Timedelta = pd.Timedelta("1h")) -> pd.Series:
     """Differentiation.
 
@@ -76,7 +82,7 @@ def window_index(np_datetime_ns: npt.NDArray[np.float64], windowlength_in_ns: in
     """
     from_to_index = np.zeros(len(np_datetime_ns), dtype=np.int64)
     end = np_datetime_ns[len(np_datetime_ns) - 1]
-    for i in prange(len(from_to_index)):
+    for i in range(len(from_to_index)):
         end_of_window_ns = np_datetime_ns[i] + windowlength_in_ns
         from_to_index[i] = (np.abs(np_datetime_ns - end_of_window_ns)).argmin()  # finds the nearest index
         if end <= np_datetime_ns[i] + windowlength_in_ns:
@@ -102,6 +108,9 @@ def integrate_windows(
     Returns:
         numpy.ndarray: The result of each integrated window.
     """
+    if prange is None:
+        raise ImportError(NUMBA_REQUIRED)
+
     res = np.empty(number_of_windows, dtype=np.float64)
     for i in prange(number_of_windows):
         cumulative = 0  # reset accumulator for new window (but numba does parallel magic in the background)
