@@ -1,6 +1,7 @@
+# Copyright 2023 Cognite AS
 from functools import wraps
 
-from typeguard import typechecked
+from typeguard import TypeCheckError, typechecked
 
 from indsl.exceptions import UserTypeError
 
@@ -12,7 +13,7 @@ def error_handling(operation):
     def wrapper(*args, **kwargs):
         try:
             return operation(*args, **kwargs)
-        except TypeError as e:
+        except TypeCheckError as e:
             raise UserTypeError(str(e)) from e
 
     return wrapper
